quantile.mcmc <- 
function(x, ...)
{
    dclone:::quantile.mcmc.list(as.mcmc.list(x), ...)
}
